@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bug_relationship_delete.php,v 1.7 2004/11/02 19:51:54 marcelloscata Exp $
+	# $Id: bug_relationship_delete.php,v 1.10 2005/07/25 16:34:10 thraxisp Exp $
 	# --------------------------------------------------------
 
 	# ======================================================================
@@ -27,10 +27,6 @@
 	$f_rel_id = gpc_get_int( 'rel_id' );
 	$f_bug_id = gpc_get_int( 'bug_id' );
 
-	if ( current_user_is_anonymous()) {
-		access_denied();
-	}
-
 	# user has access to update the bug...
 	access_ensure_bug_level( config_get( 'update_bug_threshold' ), $f_bug_id );
 
@@ -40,6 +36,13 @@
 		trigger_error( ERROR_BUG_READ_ONLY_ACTION_DENIED, ERROR );
 	}
 
+	$t_bug = bug_get( $f_bug_id, true );
+	if( $t_bug->project_id != helper_get_current_project() ) {
+		# in case the current project is not the same project of the bug we are viewing...
+		# ... override the current project. This to avoid problems with categories and handlers lists etc.
+		$g_project_override = $t_bug->project_id;
+	}
+
 	# retrieve the destination bug of the relationship
 	$t_dest_bug_id = relationship_get_linked_bug_id( $f_rel_id, $f_bug_id );
 
@@ -83,4 +86,4 @@
 	}
 
 	print_header_redirect_view( $f_bug_id );
-?>
\ No newline at end of file
+?>
