@@ -1,12 +1,12 @@
 <?php
 	# Mantis - a php based bugtracking system
 	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+	# Copyright (C) 2002 - 2006  Mantis Team   - mantisbt-dev@lists.sourceforge.net
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: config_defaults_inc.php,v 1.225.2.1.2.1 2005/12/13 11:27:54 vboctor Exp $
+	# $Id: config_defaults_inc.php,v 1.283.2.1.2.1.2.1.2.2.2.12 2006/10/29 00:20:29 vboctor Exp $
 	# --------------------------------------------------------
 
 
@@ -23,7 +23,7 @@
 	# In general a value of OFF means the feature is disabled and ON means the
 	# feature is enabled.  Any other cases will have an explanation.
 
-	# For more details see http://manual.mantisbt.org/
+	# For more details see http://manual.mantisbugtracker.com/
 
 	################################
 	# Mantis Database Settings
@@ -41,6 +41,8 @@
 	$g_db_username			= 'root';
 	$g_db_password			= '';
 	$g_database_name		= 'bugtracker';
+
+	# Supported types: mysql for MySQL, mysqli for MySQL, pgsql for PostgreSQL, mssql for MS SQL Server, oci8 for Oracle.
 	$g_db_type			= 'mysql';
 
 	############################
@@ -78,7 +80,7 @@
 			$t_host = 'www.example.com';
 		}
 
-		$t_path = dirname( $_SERVER['PHP_SELF'] );
+		$t_path = dirname( strip_tags( $_SERVER['PHP_SELF'] ) );
 		if ( '/' == $t_path || '\\' == $t_path ) {
 			$t_path = '';
 		}
@@ -90,7 +92,7 @@
 
 	# path to your images directory (for icons)
 	# requires trailing /
-	$g_icon_path			= $g_path.'images/';
+	$g_icon_path			= '%path%images/';
 
 	# absolute path to your installation.  Requires trailing / or \
 	# Symbolic links are allowed since release 0.17.3
@@ -98,10 +100,10 @@
 
 	# absolute patch to your core files. The default is usually OK,
 	# unless you moved the 'core' directory out of your webroot (recommended).
-	$g_core_path			= $g_absolute_path.'core' . DIRECTORY_SEPARATOR;
+	$g_core_path			= $g_absolute_path . 'core' . DIRECTORY_SEPARATOR;
 
 	# Used to link to manual for User Documentation.
-	$g_manual_url = 'http://manual.mantisbt.org/';
+	$g_manual_url = 'http://manual.mantisbugtracker.com/';
 
 	#############################
 	# Web Server
@@ -114,6 +116,20 @@
 		$g_use_iis = OFF;
 	}
 
+
+	#############################
+	# Configuration Settings
+	#############################
+
+	# The following list of variables should never be in the database.
+	# These patterns will be concatenated and used as a regular expression
+	# to bypass the database lookup and look here for appropriate global settings.
+	$g_global_settings = array(
+		'_table$', 'cookie', '^db_', 'hostname', 'database_name',
+		'_path$', 'use_iis', 'language', 'use_javascript', 'display_errors', 'stop_on_errors', 'login_method', '_file$',
+		'anonymous', 'content_expire', 'html_valid_tags', 'custom_headers'
+	);
+
 	#############################
 	# Signup and Lost Password
 	#############################
@@ -148,7 +164,7 @@
 	$g_signup_use_captcha	= ON;
 
 	# absolute path (with trailing slash!) to folder which contains your TrueType-Font files
-	# used to create the captcha image
+	# used to create the captcha image and since 0.19.3 for the Relationship Graphs
 	$g_system_font_folder	= 'c:/winnt/fonts/';
 
 	# font name used to create the captcha image. i.e. arial.ttf
@@ -298,7 +314,7 @@
 	#############################
 
 	# --- version variables -----------
-	$g_mantis_version		= '0.19.4';
+	$g_mantis_version		= '1.0.6';
 	$g_show_version			= ON;
 
 	################################
@@ -315,35 +331,48 @@
 	# list the choices that the users are allowed to choose
 	$g_language_choices_arr	= array(
 		'auto',
+		'bulgarian',
+		'catalan',
 		'chinese_simplified',
+		'chinese_simplified_utf8',
 		'chinese_traditional',
+		'chinese_traditional_utf8',
 		'croatian',
 		'czech',
+		'czech_utf8',
 		'danish',
 		'dutch',
 		'english',
 		'estonian',
 		'finnish',
 		'french',
+		'french_utf8',
+		'french_canadian',
 		'german',
 		'hungarian',
+		'icelandic',
 		'italian',
+		'italian_utf8',
 		'japanese_euc',
 		'japanese_sjis',
 		'japanese_utf8',
 		'korean',
+		'korean_utf8',
 		'latvian',
 		'lithuanian',
 		'norwegian',
 		'polish',
+		'polish_utf8',
 		'portuguese_brazil',
 		'portuguese_standard',
 		'romanian',
 		'russian',
 		'russian_koi8',
+		'russian_utf8',
 		'serbian',
 		'slovak',
 		'slovene',
+		'slovene_utf8',
 		'spanish',
 		'swedish',
 		'turkish',
@@ -352,33 +381,40 @@
 
 	# Browser language mapping for 'auto' language selection
 	$g_language_auto_map = array(
-		'en-us, en-gb, en-au, en' => 'english',
+		'bg' => 'bulgarian',
+		'ca' => 'catalan',
 		'zh-cn, zh-sg, zh' => 'chinese_simplified',
 		'zh-hk, zh-tw' => 'chinese_traditional',
 		'cs' => 'czech',
 		'da' => 'danish',
 		'nl-be, nl' => 'dutch',
+		'en-us, en-gb, en-au, en' => 'english',
 		'et' => 'estonian',
 		'fi' => 'finnish',
-		'fr-be, fr-ca, fr-ch, fr' => 'french',
+		'fr-be, fr-ch, fr' => 'french',
+		'fr-ca' => 'french_canadian',
 		'de-de, de-at, de-ch, de' => 'german',
 		'hu' => 'hungarian',
+		'hr' => 'croatian',
+		'is' => 'icelandic',
 		'it-ch, it' => 'italian',
-		'ja' => 'japanese_sjis',
+		'ja' => 'japanese_utf8',
 		'ko' => 'korean',
 		'lt' => 'lithuanian',
+		'lv' => 'latvian',
 		'no' => 'norwegian',
 		'pl' => 'polish',
 		'pt-br' => 'portugese_brazil',
 		'pt' => 'portugese_standard',
 		'ro-mo, ro' => 'romanian',
-		'ru-mo, ru' => 'russian',
+		'ru-mo, ru-ru, ru-ua, ru' => 'russian',
 		'sr' => 'serbian',
 		'sk' => 'slovak',
 		'sl' => 'slovene',
 		'es-mx, es-co, es-ar, es-cl, es-pr, es' => 'spanish',
 		'sv-fi, sv' => 'swedish',
-		'tr' => 'turkish'
+		'tr' => 'turkish',
+		'uk' => 'ukrainian'
 	);
 
 	# Fallback for automatic language selection
@@ -390,7 +426,7 @@
 
 	# --- sitewide variables ----------
 	$g_window_title			= 'Mantis';	 # browser window title
-	$g_page_title			= 'Mantis';	 # title at top of html page
+	$g_page_title			= '';	 # title at top of html page (empty by default, since there is a logo now)
 
 	# --- advanced views --------------
 	# BOTH, SIMPLE_ONLY, ADVANCED_ONLY
@@ -425,6 +461,15 @@
 	# --- see constant_inc.php. (*: BOTTOM or TOP)
 	$g_status_legend_position	= STATUS_LEGEND_POSITION_BOTTOM;
 
+	# --- Position of the filter box, can be: FILTER_POSITION_*
+	# FILTER_POSITION_TOP, FILTER_POSITION_BOTTOM, or 0 for none.
+	$g_filter_position	= FILTER_POSITION_TOP;
+
+	# --- Show a legend with percentage of bug status
+	# --- x% of all bugs are new, y% of all bugs are assigned and so on.
+	# --- If set to ON it will printed below the status colour legend.
+	$g_status_percentage_legend = OFF;
+
 	# --- show product versions in create, view and update screens
 	#  ON forces display even if none are defined
 	#  OFF suppresses display
@@ -435,6 +480,9 @@
 	$g_show_realname = OFF;
 	$g_differentiate_duplicates = OFF;  # leave off for now
 
+	# -- sorting for names in dropdown lists. If turned on, "Jane Doe" will be sorted with the "D"s
+	$g_sort_by_last_name = OFF;
+
 	############################
 	# Mantis JPGRAPH Addon
 	############################
@@ -451,6 +499,19 @@
 	$g_use_jpgraph			= OFF;
 	$g_jpgraph_path			= '.' . DIRECTORY_SEPARATOR . 'jpgraph' . DIRECTORY_SEPARATOR;   # dont forget the ending slash!
 
+	# what truetype font will the graphs use. Allowed values are 'arial', 'verdana', 'courier', 'book', 'comic', 'times',
+	#  'georgia', 'trebuche', 'vera', 'veramono', or 'veraserif'. Refer to the jpgraph manual for details.
+	# NOTE: these fonts need to be installed in the TTF_DIR as specified to jpgraph
+	$g_graph_font = '';
+
+	# what width is used to scale the graphs.
+	$g_graph_window_width = 800;
+	# bar graph aspect ration (height / width)
+	$g_graph_bar_aspect = 0.9;
+
+	# how many graphs to put in each row in the advanced summary page
+	$g_graph_summary_graphs_per_row = 2;
+
 	############################
 	# Mantis Time Settings
 	############################
@@ -511,11 +572,17 @@
 	# look in constant_inc.php for values
 	$g_default_new_account_access_level	= REPORTER;
 
-        # Default Bug View Status (VS_PUBLIC or VS_PRIVATE)
-        $g_default_bug_view_status = VS_PUBLIC;
+	# Default Bug View Status (VS_PUBLIC or VS_PRIVATE)
+	$g_default_bug_view_status = VS_PUBLIC;
 
-        # Default Bugnote View Status (VS_PUBLIC or VS_PRIVATE)
-        $g_default_bugnote_view_status = VS_PUBLIC;
+	# Default value for steps to reproduce field.
+	$g_default_bug_steps_to_reproduce = '';
+
+	# Default value for addition information field.
+	$g_default_bug_additional_info = '';
+
+	# Default Bugnote View Status (VS_PUBLIC or VS_PRIVATE)
+	$g_default_bugnote_view_status = VS_PUBLIC;
 
 	# Default bug severity when reporting a new bug
 	$g_default_bug_severity = MINOR;
@@ -528,6 +595,7 @@
 	$g_default_limit_view	= 50;
 	$g_default_show_changed	= 6;
 	$g_hide_status_default 	= CLOSED;
+	$g_show_sticky_issues   = 'on';
 
 	# make sure people aren't refreshing too often
 	$g_min_refresh_delay	= 10;    # in minutes
@@ -555,7 +623,7 @@
 	$g_default_email_on_closed_minimum_severity		= OFF; # 'any'
 	$g_default_email_on_reopened_minimum_severity	= OFF; # 'any'
 	$g_default_email_on_bugnote_minimum_severity	= OFF; # 'any'
-	$g_default_email_on_status_minimum_severity		= OFF; # @@@ Unused
+	$g_default_email_on_status_minimum_severity		= OFF; # 'any'
 	$g_default_email_on_priority_minimum_severity	= OFF; # @@@ Unused
 	$g_default_email_bugnote_limit					= 0;
 	# default_language - is set to site language
@@ -682,6 +750,9 @@
 	# Eg: doc-001-myprojdoc.zip
 	$g_document_files_prefix = 'doc';
 
+	# absolute path to the default upload folder.  Requires trailing / or \
+	$g_absolute_path_default_upload_folder = '';
+
 	############################
 	# Mantis HTML Settings
 	############################
@@ -696,6 +767,15 @@
 	# do NOT include tags that have parameters (eg. <font face="arial">)
 	$g_html_valid_tags		= 'p, li, ul, ol, br, pre, i, b, u';
 
+	# maximum length of the description in a dropdown menu (for search)
+	# set to 0 to disable truncations
+	$g_max_dropdown_length = 40;
+
+	# This flag conntrolls whether pre-formatted text (delimited by <pre> tags
+	#  is wrapped to a maximum linelength (defaults to 100 chars in strings_api)
+	#  If turned off, the display may be wide when viewing the text
+	$g_wrap_in_preformatted_text = ON;
+
 	##########################
 	# Mantis HR Settings
 	##########################
@@ -714,7 +794,7 @@
 	$g_ldap_server			= 'ldaps://ldap.example.com.au/';
 	$g_ldap_port			= '636';
 	$g_ldap_root_dn			= 'dc=example,dc=com,dc=au';
-	$g_ldap_organization		= '';    # e.g. '(organizationname=*Traffic)'
+	$g_ldap_organization	= '';    # e.g. '(organizationname=*Traffic)'
 	$g_ldap_uid_field		= 'uid'; # Use 'sAMAccountName' for Active Directory
 	$g_ldap_bind_dn			= '';
 	$g_ldap_bind_passwd		= '';
@@ -832,7 +912,7 @@
 	#  the Assigned list in bug_update*_page.
 	#  This allows control over who can route bugs
 	# This defaults to $g_handle_bug_threshold
-	# $g_update_bug_assign_threshold			= DEVELOPER;
+	$g_update_bug_assign_threshold			= '%handle_bug_threshold%';
 
 	# access level needed to view private bugnotes
 	# Look in the constant_inc.php file if you want to set a different value
@@ -848,7 +928,7 @@
 
 	# access level needed to send a reminder from the bug view pages
 	# set to NOBODY to disable the feature
-	$g_bug_reminder_threshold		= REPORTER;
+	$g_bug_reminder_threshold		= DEVELOPER;
 
 	# access level needed to upload files to the project documentation section
 	# You can set this to NOBODY to prevent uploads to projects
@@ -901,7 +981,7 @@
 	$g_delete_bug_threshold = DEVELOPER;
 
 	# Delete bugnote threshold
-	$g_delete_bugnote_threshold = $g_delete_bug_threshold;
+	$g_delete_bugnote_threshold = '%delete_bug_threshold%';
 
 	# Are users allowed to change and delete their own bugnotes?
 	$g_bugnote_allow_user_edit_delete = ON;
@@ -932,6 +1012,9 @@
 	# $g_bug_readonly_status_threshold.
 	$g_update_readonly_bug_threshold = MANAGER;
 
+	# Threshold needed to be able to create and modify global profiles
+	$g_manage_global_profile_threshold = MANAGER;
+
 	# threshold for viewing changelog
 	$g_view_changelog_threshold = VIEWER;
 
@@ -941,6 +1024,9 @@
 	# access level needed to re-open bugs
 	$g_reopen_bug_threshold			= DEVELOPER;
 
+	# access level needed to set a bug sticky
+	$g_set_bug_sticky_threshold			= MANAGER;
+
 	# this array sets the access thresholds needed to enter each status listed.
 	# if a status is not listed, it falls back to $g_update_bug_status_threshold
 	# example: $g_set_status_threshold = array( ACKNOWLEDGED => MANAGER, CONFIRMED => DEVELOPER, CLOSED => MANAGER );
@@ -996,15 +1082,25 @@
 	# private ones (DEVELOPER access recommended).
 	$g_source_control_account           = '';
 
-	# If set to a status, then after a checkin, the issue status is set to the
-	# specified status, otherwise if set to OFF, the issue status is not affected.
+	# If set to a status, then after a checkin with a log message that matches the regular expression in
+	# $g_source_control_fixed_regexp, the issue status is set to the specified status.  If set to OFF, the
+	# issue status is not changed.
 	$g_source_control_set_status_to     = OFF;
 
+	# Whenever an issue status is set to $g_source_control_set_status_to, the issue resolution is set to
+	# the value specified for this configuration.
+	$g_source_control_set_resolution_to = FIXED;
+
 	# Regular expression used to detect issue ids within checkin comments.
 	# see preg_match_all() documentation at
 	# http://www.php.net/manual/en/function.preg-match-all.php
 	$g_source_control_regexp = "/\bissue [#]{0,1}(\d+)\b/i";
 
+	# Regular expression used to detect the fact that an issue is fixed and extracts
+	# its issue id.  If there is a match to this regular expression, then the issue
+	# will be marked as resolved and the resolution will be set to fixed.
+	$g_source_control_fixed_regexp = "%source_control_regexp%";
+
 	# --- Bug Linking ---------------
 	# if a number follows this tag it will create a link to a bug.
 	# eg. for # a link would be #45
@@ -1044,6 +1140,9 @@
 	# Set the csv separator
 	$g_csv_separator = ',';
 
+	# threshold for users to view the system configurations
+	$g_view_configuration_threshold = DEVELOPER;
+
 	################################
 	# Mantis Look and Feel Variables
 	################################
@@ -1070,6 +1169,10 @@
 	#  The bugnote id will be padded with 0's up to the size given
 	$g_display_bugnote_padding	= 7;
 
+	# colours for configuration display
+	$g_colour_project = 'LightGreen';
+	$g_colour_global = 'LightBlue';
+
 	###############################
 	# Mantis Cookie Variables
 	###############################
@@ -1080,60 +1183,69 @@
 	$g_cookie_path			= '/';
 	$g_cookie_domain		= '';
 	# cookie version for view_all_page
-	$g_cookie_version		= 'v5';
+	$g_cookie_version		= 'v7';
 
 	# --- cookie prefix ---------------
 	# set this to a unique identifier.  No spaces.
 	$g_cookie_prefix		= 'MANTIS';
 
 	# --- cookie names ----------------
-	$g_string_cookie		= $g_cookie_prefix.'_STRING_COOKIE';
-	$g_project_cookie		= $g_cookie_prefix.'_PROJECT_COOKIE';
-	$g_view_all_cookie		= $g_cookie_prefix.'_VIEW_ALL_COOKIE';
-	$g_manage_cookie		= $g_cookie_prefix.'_MANAGE_COOKIE';
-	$g_logout_cookie		= $g_cookie_prefix.'_LOGOUT_COOKIE';
-	$g_bug_list_cookie		= $g_cookie_prefix.'_BUG_LIST_COOKIE';
+	$g_string_cookie		= '%cookie_prefix%_STRING_COOKIE';
+	$g_project_cookie		= '%cookie_prefix%_PROJECT_COOKIE';
+	$g_view_all_cookie		= '%cookie_prefix%_VIEW_ALL_COOKIE';
+	$g_manage_cookie		= '%cookie_prefix%_MANAGE_COOKIE';
+	$g_logout_cookie		= '%cookie_prefix%_LOGOUT_COOKIE';
+	$g_bug_list_cookie		= '%cookie_prefix%_BUG_LIST_COOKIE';
 
 	#######################################
 	# Mantis Filter Variables
 	#######################################
 	$g_filter_by_custom_fields = ON;
-	$g_filter_custom_fields_per_row = 7;
+	$g_filter_custom_fields_per_row = 8;
 	$g_view_filters = SIMPLE_DEFAULT;
 
+	# This switch enables the use of xmlhttprequest protocol to speed up the filter display.
+	# Rather than launching a separate page, the filters are updated in-line in the
+	# view_all_bugs_page.
+	$g_dhtml_filters = ON;
+
 	#######################################
 	# Mantis Database Table Variables
 	#######################################
 
 	# --- table prefix ----------------
-	# if you change this remember to reflect the changes in the database
 	$g_db_table_prefix		= 'mantis';
+	$g_db_table_suffix		= '_table';
 
 	# --- table names -----------------
-	$g_mantis_bug_file_table				= $g_db_table_prefix.'_bug_file_table';
-	$g_mantis_bug_history_table				= $g_db_table_prefix.'_bug_history_table';
-	$g_mantis_bug_monitor_table				= $g_db_table_prefix.'_bug_monitor_table';
-	$g_mantis_bug_relationship_table		= $g_db_table_prefix.'_bug_relationship_table';
-	$g_mantis_bug_table						= $g_db_table_prefix.'_bug_table';
-	$g_mantis_bug_text_table				= $g_db_table_prefix.'_bug_text_table';
-	$g_mantis_bugnote_table					= $g_db_table_prefix.'_bugnote_table';
-	$g_mantis_bugnote_text_table			= $g_db_table_prefix.'_bugnote_text_table';
-	$g_mantis_news_table					= $g_db_table_prefix.'_news_table';
-	$g_mantis_project_category_table		= $g_db_table_prefix.'_project_category_table';
-	$g_mantis_project_file_table			= $g_db_table_prefix.'_project_file_table';
-	$g_mantis_project_table					= $g_db_table_prefix.'_project_table';
-	$g_mantis_project_user_list_table		= $g_db_table_prefix.'_project_user_list_table';
-	$g_mantis_project_version_table			= $g_db_table_prefix.'_project_version_table';
-	$g_mantis_user_table					= $g_db_table_prefix.'_user_table';
-	$g_mantis_user_profile_table			= $g_db_table_prefix.'_user_profile_table';
-	$g_mantis_user_pref_table				= $g_db_table_prefix.'_user_pref_table';
-	$g_mantis_user_print_pref_table			= $g_db_table_prefix.'_user_print_pref_table';
-	$g_mantis_custom_field_project_table	= $g_db_table_prefix.'_custom_field_project_table';
-	$g_mantis_custom_field_table      	    = $g_db_table_prefix.'_custom_field_table';
-	$g_mantis_custom_field_string_table     = $g_db_table_prefix.'_custom_field_string_table';
-	$g_mantis_upgrade_table					= $g_db_table_prefix.'_upgrade_table';
-	$g_mantis_filters_table					= $g_db_table_prefix.'_filters_table';
-	$g_mantis_sponsorship_table				= $g_db_table_prefix.'_sponsorship_table';
+	$g_mantis_bug_file_table				= '%db_table_prefix%_bug_file%db_table_suffix%';
+	$g_mantis_bug_history_table				= '%db_table_prefix%_bug_history%db_table_suffix%';
+	$g_mantis_bug_monitor_table				= '%db_table_prefix%_bug_monitor%db_table_suffix%';
+	$g_mantis_bug_relationship_table		= '%db_table_prefix%_bug_relationship%db_table_suffix%';
+	$g_mantis_bug_table						= '%db_table_prefix%_bug%db_table_suffix%';
+	$g_mantis_bug_text_table				= '%db_table_prefix%_bug_text%db_table_suffix%';
+	$g_mantis_bugnote_table					= '%db_table_prefix%_bugnote%db_table_suffix%';
+	$g_mantis_bugnote_text_table			= '%db_table_prefix%_bugnote_text%db_table_suffix%';
+	$g_mantis_news_table					= '%db_table_prefix%_news%db_table_suffix%';
+	$g_mantis_project_category_table		= '%db_table_prefix%_project_category%db_table_suffix%';
+	$g_mantis_project_file_table			= '%db_table_prefix%_project_file%db_table_suffix%';
+	$g_mantis_project_table					= '%db_table_prefix%_project%db_table_suffix%';
+	$g_mantis_project_user_list_table		= '%db_table_prefix%_project_user_list%db_table_suffix%';
+	$g_mantis_project_version_table			= '%db_table_prefix%_project_version%db_table_suffix%';
+	$g_mantis_user_table					= '%db_table_prefix%_user%db_table_suffix%';
+	$g_mantis_user_profile_table			= '%db_table_prefix%_user_profile%db_table_suffix%';
+	$g_mantis_user_pref_table				= '%db_table_prefix%_user_pref%db_table_suffix%';
+	$g_mantis_user_print_pref_table			= '%db_table_prefix%_user_print_pref%db_table_suffix%';
+	$g_mantis_custom_field_project_table	= '%db_table_prefix%_custom_field_project%db_table_suffix%';
+	$g_mantis_custom_field_table      	    = '%db_table_prefix%_custom_field%db_table_suffix%';
+	$g_mantis_custom_field_string_table     = '%db_table_prefix%_custom_field_string%db_table_suffix%';
+	$g_mantis_upgrade_table					= '%db_table_prefix%_upgrade%db_table_suffix%';
+	$g_mantis_filters_table					= '%db_table_prefix%_filters%db_table_suffix%';
+	$g_mantis_sponsorship_table				= '%db_table_prefix%_sponsorship%db_table_suffix%';
+	$g_mantis_tokens_table					= '%db_table_prefix%_tokens%db_table_suffix%';
+	$g_mantis_project_hierarchy_table		= '%db_table_prefix%_project_hierarchy%db_table_suffix%';
+	$g_mantis_config_table					= '%db_table_prefix%_config%db_table_suffix%';
+	$g_mantis_database_table					= '%db_table_prefix%_database%db_table_suffix%';
 
 	###########################
 	# Mantis Enum Strings
@@ -1158,8 +1270,9 @@
 	$g_resolution_enum_string			= '10:open,20:fixed,30:reopened,40:unable to duplicate,50:not fixable,60:duplicate,70:not a bug,80:suspended,90:wont fix';
 	$g_projection_enum_string			= '10:none,30:tweak,50:minor fix,70:major rework,90:redesign';
 	$g_eta_enum_string					= '10:none,20:< 1 day,30:2-3 days,40:< 1 week,50:< 1 month,60:> 1 month';
+	$g_sponsorship_enum_string          = '0:Unpaid,1:Requested,2:Paid';
 
-	$g_custom_field_type_enum_string    = '0:string,1:numeric,2:float,3:enum,4:email,5:checkbox,6:list,7:multiselection list';
+	$g_custom_field_type_enum_string    = '0:string,1:numeric,2:float,3:enum,4:email,5:checkbox,6:list,7:multiselection list,8:date';
 
 	#############################
 	# Mantis Javascript Variables
@@ -1193,19 +1306,20 @@
 	###########################
 
 	# Specify your top/bottom include file (logos, banners, etc)
-	$g_bottom_include_page			= $g_absolute_path.'';
-	$g_top_include_page				= $g_absolute_path.'';
+	# if a top file is supplied, the default Mantis logo at the top will be hidden
+	$g_bottom_include_page			= '%absolute_path%';
+	$g_top_include_page				= '%absolute_path%';
 	# CSS file
-	$g_css_include_file				= $g_path.'css/default.css';
+	$g_css_include_file				= '%path%css/default.css';
 	# meta tags
-	$g_meta_include_file			= $g_absolute_path.'meta_inc.php';
+	$g_meta_include_file			= '%absolute_path%meta_inc.php';
 
 	###########################
 	# Redirections
 	###########################
 
 	# Specify where the user should be sent after logging out.
-	$g_logout_redirect_page			= $g_path.'login_page.php';
+	$g_logout_redirect_page			= '%path%login_page.php';
 
 	###########################
 	# Headers
@@ -1223,6 +1337,19 @@
 	$g_custom_headers				= array();
 	#$g_custom_headers[]			= 'P3P: CP="CUR ADM"';
 
+	# Browser Caching Control
+	# By default, we try to prevent the browser from caching anything. These two settings
+	# will defeat this for some cases.
+	#
+	# Browser Page caching - This will allow the browser to cache all pages. The upside will
+	#  be better performance, but there may be cases where obsolete information is displayed.
+	#  Note that this will be bypassed (and caching is allowed) for the bug report pages.
+	# $g_allow_browser_cache = ON;
+	#
+	# File caching - This will allow the browser to cache downloaded files. Without this set,
+	# there may be issues with IE receiving files, and launching support programs.
+	# $g_allow_file_cache = ON;
+
 	###########################
 	# Debugging
 	###########################
@@ -1270,10 +1397,10 @@
 	#	);
 
 	$g_display_errors = array(
-		E_WARNING => 'none',
+		E_WARNING => 'inline',
 		E_NOTICE => 'none',
 		E_USER_ERROR => 'halt',
-		E_USER_WARNING => 'none',
+		E_USER_WARNING => 'inline',
 		E_USER_NOTICE => 'none'
 	);
 
@@ -1297,6 +1424,19 @@
 	# Only turn this option on for debugging
 	$g_stop_on_errors		= OFF;
 
+	# --- system logging ---
+	# This controls the logging of information to a separate file for debug or audit
+	# $g_log_level controls what information is logged
+	#  see constant_inc.php for details on the log channels available
+	#  e.g., $g_log_level = LOG_EMAIL | LOG_PROJECT;
+	#
+	# $g_log_destination specifies the file where the data goes
+	#   right now, only "file:<file path>" is supported
+	#   e.g., $g_log_destination = 'file:/tmp/mantis_log';
+	#   see http://www.php.net/error_log for details
+	$g_log_level = 0;
+	$g_log_destination = '';
+
 	##################
 	# Custom Fields
 	##################
@@ -1399,7 +1539,9 @@
 		'reported'      => '3',
 		'resolved'      => '4',
 		'recent_mod'	=> '5',
-		'monitored'	=> '6'
+		'monitored'		=> '6',
+		'feedback'		=> '0',
+		'verify'		=> '0'
 	);
 
 	# Toggle whether 'My View' boxes are shown in a fixed position (i.e. adjacent boxes start at the same vertical position)
@@ -1437,8 +1579,7 @@
 	$g_relationship_graph_fontname		= 'Arial';
 	$g_relationship_graph_fontsize		= 8;
 
-	# Local path where the above font is found on your system.
-	#
+	# Local path where the above font is found on your system for Relationship Graphs
 	# You shouldn't care about this on Windows since there is only one system
 	# folder where fonts are installed and Graphviz already knows where it
 	# is. On Linux and other unices, the default font search path is defined
@@ -1451,7 +1592,8 @@
 	# the DOTFONTPATH environment variable in your webserver startup script
 	# or (2) use this config option conveniently available here. If you need
 	# to list more than one directory, use colons to separate them.
-	$g_relationship_graph_fontpath		= '';
+
+	# Since 0.19.3 we use the $g_system_font_folder variable to define the font folder
 
 	# Default dependency orientation. If you have issues with lots of childs
 	# or parents, leave as 'horizontal', otherwise, if you have lots of
@@ -1474,4 +1616,23 @@
 	# NOTE: These are meaningless under Windows! Just ignore them!
 	$g_dot_tool							= '/usr/bin/dot';
 	$g_neato_tool						= '/usr/bin/neato';
-?>
\ No newline at end of file
+
+	# Number of years in the future that custom date fields will display in
+	# drop down boxes.
+	$g_forward_year_count 				= 4 ;
+
+	# Custom Group Actions
+	# Sample:
+	#
+	# array(
+	#	array(	'action' => 'my_custom_action',
+	#			'form_page' => 'my_custom_action_page.php',
+	#			'action_page' => 'my_custom_action.php'
+	#   )
+	#	array(	'action' => 'my_custom_action2',
+	#			'form_page' => 'my_custom_action2_page.php',
+	#			'action_page' => 'my_custom_action2.php'
+	#   )
+	# );
+	$g_custom_group_actions = array();
+?>
