@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: history_api.php,v 1.30 2004/10/05 21:10:14 prichards Exp $
+	# $Id: history_api.php,v 1.34 2005/08/27 01:15:59 thraxisp Exp $
 	# --------------------------------------------------------
 
 	### History API ###
@@ -194,6 +194,11 @@
 				$p_new_value = get_enum_element( 'projection', $p_new_value );
 				$t_field_localized = lang_get( 'projection' );
 				break;
+			case 'sticky':
+				$p_old_value = gpc_string_to_bool( $p_old_value ) ? lang_get( 'yes' ) : lang_get( 'no' ) ;
+				$p_new_value = gpc_string_to_bool( $p_new_value ) ? lang_get( 'yes' ) : lang_get( 'no' ) ;
+				$t_field_localized = lang_get( 'sticky_issue' );
+				break;
 			case 'project_id':
 				if ( project_exists( $p_old_value ) ) {
 					$p_old_value = project_get_field( $p_old_value, 'name' );
@@ -243,6 +248,19 @@
 			case 'duplicate_id':
 				$t_field_localized = lang_get( 'duplicate_id' );
 				break;
+			case 'sponsorship_total':
+				$t_field_localized = lang_get( 'sponsorship_total' );
+				break;
+			default:
+				# assume it's a custom field name
+				$t_field_id = custom_field_get_id_from_name( $p_field_name );
+				if ( false !== $t_field_id ) {
+					$t_cf_type = custom_field_type( $t_field_id );
+					if ( '' != $p_old_value ) {
+						$p_old_value = string_custom_field_value_for_email( $p_old_value, $t_cf_type ); 
+					}
+					$p_new_value = string_custom_field_value_for_email( $p_new_value, $t_cf_type ); 
+				}
 		}
 
 		if ( NORMAL_TYPE != $p_type ) {
@@ -301,6 +319,10 @@
 					$t_note = lang_get( 'sponsorship_deleted' );
 					$t_change = user_get_name( $p_old_value ) . ': ' . sponsorship_format_amount( $p_new_value );
 					break;
+				case BUG_PAID_SPONSORSHIP:
+					$t_note = lang_get( 'sponsorship_paid' );
+					$t_change = user_get_name( $p_old_value ) . ': ' . get_enum_element( 'sponsorship', $p_new_value );
+					break;
 				case BUG_ADD_RELATIONSHIP:
 					$t_note = lang_get( 'relationship_added' );
 					$t_change = relationship_get_description_for_history( $p_old_value ) . ' ' . bug_format_id( $p_new_value );
