@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: manage_proj_edit_page.php,v 1.92.6.1 2006/01/01 02:58:50 thraxisp Exp $
+	# $Id: manage_proj_edit_page.php,v 1.92.6.1.4.2 2006/09/23 06:48:45 vboctor Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -164,7 +164,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 
 <!-- Subprojects -->
 <?php
-	$t_subproject_ids = current_user_get_accessible_subprojects( $f_project_id );
+	$t_subproject_ids = current_user_get_accessible_subprojects( $f_project_id, /* show_disabled */ true );
 
 	if ( Array() != $t_subproject_ids ) {
 ?>
@@ -229,7 +229,7 @@ if ( access_has_global_level ( config_get( 'delete_project_threshold' ) ) ) { ?>
 			<input type="hidden" name="project_id" value="<?php echo $f_project_id ?>" />
 			<select name="subproject_id">
 <?php
-	$t_all_subprojects = project_hierarchy_get_subprojects( $f_project_id );
+	$t_all_subprojects = project_hierarchy_get_subprojects( $f_project_id, /* $p_show_disabled */ true );
 	$t_all_subprojects[] = $f_project_id;
 	$t_manage_access = config_get( 'manage_project_threshold' );
 
@@ -566,8 +566,8 @@ if ( access_has_project_level( config_get( 'project_user_threshold' ), $f_projec
 				</td>
 				<td>
 					<select name="access_level">
-						<?php # No administrator choice ?>
-						<?php print_project_access_levels_option_list( config_get( 'default_new_account_access_level' ) ) ?>
+						<?php # only access levels that are less than or equal current user access level for current project ?>
+						<?php print_project_access_levels_option_list( config_get( 'default_new_account_access_level' ), $f_project_id ) ?>
 					</select>
 				</td>
 				<td>
