@@ -6,28 +6,27 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: manage_user_delete.php,v 1.29 2004/08/21 00:41:32 prichards Exp $
+	# $Id: manage_user_delete.php,v 1.30 2004/12/14 20:37:07 marcelloscata Exp $
 	# --------------------------------------------------------
-?>
-<?php require_once( 'core.php' ) ?>
-<?php
+
+	require_once( 'core.php' );
+
 	access_ensure_global_level( config_get( 'manage_user_threshold' ) );
-	
+
 	$f_user_id	= gpc_get_int( 'user_id' );
 
 	$t_user = user_get_row( $f_user_id );
 
-	helper_ensure_confirmed( lang_get( 'delete_account_sure_msg' ) . '<br/>' . lang_get( 'username' ) . ': ' . $t_user['username'],
-							 lang_get( 'delete_account_button' ) );
+	helper_ensure_confirmed( lang_get( 'delete_account_sure_msg' ) .
+		'<br/>' . lang_get( 'username' ) . ': ' . $t_user['username'],
+		lang_get( 'delete_account_button' ) );
 
 	user_delete( $f_user_id );
 
 	$t_redirect_url = 'manage_user_page.php';
 
 	html_page_top1();
-
 	html_meta_redirect( $t_redirect_url );
-
 	html_page_top2();
 ?>
 
@@ -35,7 +34,6 @@
 <div align="center">
 <?php
 	echo lang_get( 'operation_successful' ) . '<br />';
-
 	print_bracket_link( $t_redirect_url, lang_get( 'proceed' ) );
 ?>
 </div>
